============
Optimization
============

Optimization commands are used to perform topology, shape, or sizing optimization of your model given a set of objectives and a set of restrictions.

Create optimization tasks
-------------------------

.. autoclass:: abaqus.Optimization.OptimizationTaskModel.OptimizationTaskModel
    :noindex:

    .. autoclasstoc::

Assign features to optimization tasks
-------------------------------------

.. autoclass:: abaqus.Optimization.OptimizationTask.OptimizationTask
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
